@@ -23,49 +23,65 @@ from pysource import client
 from pysource import config
 
 
-def daemon(action):
-    if action == 'start':
+class DaemonCommands(object):
+    """Daemon related commands"""
+
+    namespace = 'daemon'
+
+    @staticmethod
+    def start():
+        """start the daemon process"""
         started = daemonizer.start()
         if not started:
-            return 'Daemon already started'
-    elif action == 'stop':
+            return 'daemon already started'
+
+    @staticmethod
+    def stop():
+        """stop the daemon process"""
         stopped = daemonizer.stop()
         if stopped:
-            return 'Daemon stopped'
+            return 'daemon stopped'
         else:
-            return 'Daemon not running'
-    elif action == 'restart':
+            return 'daemon not running'
+
+    @staticmethod
+    def restart():
+        """restart the daemon process"""
         daemonizer.restart()
-    elif action == 'status':
+
+    @staticmethod
+    def status():
+        """check the daemon process status"""
         status, pid = daemonizer.status()
         if status == daemonizer.STATUS_STOPPED:
-            return 'Daemon is (probably) stopped'
+            return 'daemon is (probably) stopped'
         elif status == daemonizer.STATUS_CORRUPTED:
             if pid:
-                return 'Daemon pidfile exists but process does not seem ' \
-                       'to be running (pid: {0}). You should probably clean ' \
+                return 'daemon pidfile exists but process does not seem ' \
+                       'to be running (pid: {0}). you should probably clean ' \
                        'the files in {1} and manually check if there' \
                        ' is a daemon running somewhere'\
                        .format(pid, config.pysource_dir)
             else:
-                return 'Daemon seems to be in an unstable state. Manually ' \
+                return 'daemon seems to be in an unstable state. manually ' \
                        'remove the files in {0} and kill leftover daemon ' \
                        'processes (if there are any)'\
                        .format(config.pysource_dir)
         else:
-            return 'Daemon is (probably) running (pid: {0})'.format(pid)
-    else:
-        raise pysource.error('unrecognized action: {0} '
-                             '[valid: start, stop, restart, status]'
-                             .format(action))
+            return 'daemon is (probably) running (pid: {0})'.format(pid)
+
+    @classmethod
+    def commands(cls):
+        return [cls.start, cls.stop, cls.restart, cls.status]
 
 
 def list_registered():
+    """list all functions currently registered"""
     descriptors = client.list_registered()
     if len(descriptors) == 0:
-        yield 'No functions registered'
+        yield 'no functions registered'
     else:
-        yield 'Registered functions:'
+        yield 'registered functions:'
         for descriptor in descriptors:
             name = descriptor['name']
             piped = descriptor['piped']
@@ -74,53 +90,76 @@ def list_registered():
 
 
 def update_env(verbose=False):
+    """
+    update environment variables at the daemon with the current client
+    environment
+    """
     status = client.update_env()
-    if status == 'updated' and verbose:
-        return 'Environment updated'
-    else:
-        raise pysource.error('Failed updating environment')
+    if status != 'updated':
+        raise pysource.error('failed updating environment')
+    if verbose:
+        return 'environment updated'
 
 
 def source_registered(verbose=False):
+    """source all functions currently registered"""
     return client.source_registered(verbose=verbose)
 
 
+@argh.arg('function_name', help='the name of the function to source')
 def source_named(function_name, piped=False, verbose=False):
+    """source a function named by the first positional argument"""
     return client.source_named(function_name,
                                piped=piped,
                                verbose=verbose)
 
 
+@argh.arg('def_content', help='the function definition itself')
 def source_def(def_content, piped=False, verbose=False):
+    """source an inline function definition"""
     return client.source_def(def_content,
                              piped=piped,
                              verbose=verbose)
 
 
+@argh.arg('content', help='the code to execute at the daemon')
 def source_inline(content, verbose=False):
+    """
+    execute arbitrary code at the daemon. if code contains function
+    definitions, they will be sourced at the client
+    """
     return client.source_content(content,
                                  verbose=verbose)
 
 
+@argh.arg('source_path', help='the path to the file to source')
 def source(source_path, verbose=False):
+    """source a file by its path"""
     return client.source_path(source_path,
                               verbose=verbose)
 
 
+@argh.arg('function_name', help='the name of the function to run')
 def run(function_name, *args):
+    """run the function named by the first positional argument"""
     result = client.run_function(function_name, args)
     if result:
         return result
 
 
+@argh.arg('function_name', help='the name of the function to run')
 def run_piped(function_name, *args):
+    """
+    run the function named by the first positional argument as a piped
+    function
+    """
     client.run_piped_function(function_name, args)
 
 
 def main():
     errors = StringIO()
-    argh.dispatch_commands([
-        daemon,
+    parser = argh.ArghParser()
+    argh.add_commands(parser, [
         source,
         run,
         run_piped,
@@ -130,7 +169,12 @@ def main():
         source_def,
         source_inline,
         update_env
-    ], completion=False, errors_file=errors)
+    ], )
+    argh.add_commands(parser,
+                      functions=DaemonCommands.commands(),
+                      namespace=DaemonCommands.namespace,
+                      title=DaemonCommands.__doc__)
+    argh.dispatch(parser, completion=False, errors_file=errors)
     if errors.len > 0:
         sys.exit(errors.getvalue().strip())
 
