@@ -321,7 +321,7 @@ class PipeControlledOutputSocket(PipeControlledBaseSocket):
         while True:
             if total_sent == total_bytes_to_write:
                 break
-            _, writable, _ = select.select([], [self.data_socket], [], 0.5)
+            _, writable, _ = select.select([], [self.data_socket], [], 30)
             if self.data_socket in writable:
                 sent = self.data_socket.send(view[total_sent:])
                 total_sent += sent
@@ -422,16 +422,7 @@ def do_piped_client_request(req_type, payload):
 
 
 def _do_client_request(req_type, payload, pipe_handler=None):
-    sock = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
-    try:
-        sock.connect(unix_socket_path())
-    except socket.error, e:
-        if e.errno in [errno.ENOENT, errno.ECONNREFUSED]:
-            raise pysource.error('Is the pysource daemon running?'
-                                 ' Run "pysource daemon start" to start it.')
-        else:
-            raise
-
+    sock = _client_connect()
     req = sock.makefile('wb', 0)
     res = sock.makefile('rb', -1)
     piped = pipe_handler is not None
@@ -460,6 +451,20 @@ def _do_client_request(req_type, payload, pipe_handler=None):
         sock.close()
 
 
+def _client_connect():
+    sock = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
+    try:
+        sock.connect(unix_socket_path())
+    except socket.error, e:
+        if e.errno in [errno.ENOENT, errno.ECONNREFUSED]:
+            raise pysource.error('Is the pysource daemon running? '
+                                 'Run "pysource daemon start" to start '
+                                 'it.')
+        else:
+            raise
+    return sock
+
+
 def _read_body(sock):
     json_body_len = int(sock.readline())
     return json.loads(sock.read(json_body_len))
